@@ -1,14 +1,13 @@
-import os
+import time
 import uuid
 
 import pytest as pytest
 
-from iomete_sdk import SparkJobApiClient, ClientError
+from iomete_sdk.spark import SparkJobApiClient
+from iomete_sdk.api_utils import ClientError
+from tests import TEST_TOKEN, TEST_HOST, TEST_DOMAIN
 
-TEST_TOKEN = os.environ.get("TEST_TOKEN")
-WORKSPACE_ID = "pceh7-816"
-
-SPARK_VERSION = "3.2.1"
+SPARK_VERSION = "3.5.3"
 
 
 def random_job_name():
@@ -19,11 +18,28 @@ def random_job_name():
 def create_payload() -> dict:
     return {
         "name": random_job_name(),
+        "namespace": "iomete-system",
+        "jobUser": "admin",
+        "jobType": "MANUAL",
         "template": {
-            "spark_version": SPARK_VERSION,
-            "main_application_file": "local:///opt/spark/examples/jars/spark-examples_2.12-3.2.1-iomete.jar",
-            "main_class": "org.apache.spark.examples.SparkPi",
-            "arguments": ["10"]
+            "applicationType": "python",
+            "image": f"iomete/spark-py:{SPARK_VERSION}-v1",
+            "mainApplicationFile": "https://raw.githubusercontent.com/iomete/query-scheduler-job/main/job.py",
+            "configMaps": [{
+                "key": "application.conf",
+                "content": "# Queries to be run sequentially\n[\n  # let's create an example SELECT\n  \"\"\"\n  SELECT 1\n  \"\"\"\n]",
+                "mountPath": "/etc/configs"
+            }],
+            "deps": {
+                "pyFiles": ["https://github.com/iomete/query-scheduler-job/raw/main/infra/dependencies.zip"]
+            },
+            "instanceConfig": {
+                "singleNodeDeployment": False, "driverType": "driver-x-small",
+                "executorType": "exec-x-small", "executorCount": 1
+            },
+            "restartPolicy": {"type": "Never"},
+            "maxExecutionDurationSeconds": "3600",
+            "volumeId": "920a140e-fc90-481a-8ec2-4e395bfa6450",
         }
     }
 
@@ -31,8 +47,9 @@ def create_payload() -> dict:
 @pytest.fixture
 def job_client():
     return SparkJobApiClient(
-        workspace_id=WORKSPACE_ID,
+        host=TEST_HOST,
         api_key=TEST_TOKEN,
+        domain=TEST_DOMAIN
     )
 
 
@@ -43,15 +60,12 @@ def test_create_job_without_name_raise_400(job_client, create_payload):
         response = job_client.create_job(payload=payload_without_name)
 
     assert err.value.status == 400
-    assert err.value.content["error_code"] == "BAD_INPUT"
-    assert "Name cannot be blank" in err.value.content["error_message"]
 
 
 def test_create_job_successful(job_client, create_payload):
     response = job_client.create_job(payload=create_payload)
 
     assert response["name"] == create_payload["name"]
-    assert response["workspace_id"] == WORKSPACE_ID
     assert response["id"] is not None
 
     # clean up
@@ -66,13 +80,13 @@ def test_update_job(job_client, create_payload):
 
     # update job
     update_payload = job_create_response.copy()
+    update_payload["jobType"] = "SCHEDULED"
     update_payload["schedule"] = cron_schedule
     job_update_response = job_client.update_job(job_id=job_create_response["id"], payload=update_payload)
 
     assert job_update_response["schedule"] == cron_schedule
-    assert job_update_response["job_type"] == "SCHEDULED"
+    assert job_update_response["jobType"] == "SCHEDULED"
     assert job_update_response["name"] == job_create_response["name"]
-    assert job_update_response["workspace_id"] == job_create_response["workspace_id"]
     assert job_update_response["id"] == job_create_response["id"]
 
     # clean up
@@ -82,10 +96,9 @@ def test_update_job(job_client, create_payload):
 def test_get_jobs(job_client):
     response = job_client.get_jobs()
 
-    assert len(response["items"]) > 0
+    assert len(response) > 0
 
-    job = response["items"][0]
-    assert job["workspace_id"] == WORKSPACE_ID
+    job = response[0]
     assert job["id"] is not None
 
 
@@ -100,7 +113,6 @@ def test_get_job_by_id(job_client, create_payload):
     assert response["permissions"] is not None
 
     job = response["item"]
-    assert job["workspace_id"] == WORKSPACE_ID
     assert job["name"] == create_payload["name"]
     assert job["id"] is not None
 
@@ -108,6 +120,53 @@ def test_get_job_by_id(job_client, create_payload):
     job_client.delete_job_by_id(job_id=job["id"])
 
 
+def test_get_job_run_by_id(job_client, create_payload):
+    job = job_client.create_job(payload=create_payload)
+    job_run = job_client.submit_job_run(job_id=job["id"], payload={})
+
+    job_run_info = job_client.get_job_run_by_id(job_id=job["id"], run_id=job_run["id"])
+
+    assert job_run_info["jobId"] == job["id"]
+    assert job_run_info["id"] == job_run["id"]
+    assert job_run_info["driverErrorMessage"] == ''
+    assert job_run_info["executionAttempts"] == 1
+
+    job_client.cancel_job_run(job_id=job["id"], run_id=job_run["id"])
+    job_client.delete_job_by_id(job_id=job["id"])
+
+
+def test_get_job_run_logs(job_client, create_payload):
+    job = job_client.create_job(payload=create_payload)
+    job_run = job_client.submit_job_run(job_id=job["id"], payload={})
+
+    job_run_logs = job_client.get_job_run_logs(job_id=job["id"], run_id=job_run["id"])
+
+    assert job_run_logs is not None
+    assert len(job_run_logs) > 0
+    assert job_run_logs[0]['date'] is not None
+    assert job_run_logs[0]['logLine'] is not None
+
+    job_client.cancel_job_run(job_id=job["id"], run_id=job_run["id"])
+    job_client.delete_job_by_id(job_id=job["id"])
+
+
+def test_get_job_run_metrics(job_client, create_payload):
+    job = job_client.create_job(payload=create_payload)
+    job_run = job_client.submit_job_run(job_id=job["id"], payload={})
+
+    time.sleep(10)
+
+    job_run_metrics = job_client.get_job_run_metrics(job_id=job["id"], run_id=job_run["id"])
+
+    assert job_run_metrics is not None
+    assert job_run_metrics["runId"] == job_run["id"]
+    assert job_run_metrics["driver"] is not None
+    assert job_run_metrics["executors"] is not None
+
+    job_client.cancel_job_run(job_id=job["id"], run_id=job_run["id"])
+    job_client.delete_job_by_id(job_id=job["id"])
+
+
 def test_delete_job_by_id(job_client, create_payload):
     # create job
     job = job_client.create_job(payload=create_payload)
@@ -123,7 +182,7 @@ def test_delete_job_by_id(job_client, create_payload):
     with pytest.raises(ClientError) as err:
         job_client.get_job_by_id(job_id=job["id"])
     assert err.value.status == 404
-    assert err.value.content["error_code"] == "NOT_FOUND"
+    assert err.value.content["errorCode"] == "NOT_FOUND"
 
 
 def test_get_job_runs(job_client, create_payload):
@@ -145,12 +204,14 @@ def test_submit_job_run(job_client, create_payload):
     job = job_client.create_job(payload=create_payload)
 
     # submit job run
-    response = job_client.submit_job_run(job_id=job["id"])
+    response = job_client.submit_job_run(job_id=job["id"], payload={})
 
     run_id = response["id"]
 
     assert run_id is not None
-    assert response["job_id"] == job["id"]
+
+    # sleep 5 seconds before cleaning up
+    time.sleep(5)
 
     # clean up
     job_client.cancel_job_run(job_id=job["id"], run_id=run_id)
